//==============================================================================================
//
//	Windows Interface Construction Set
//	Version 1.00
//
//	HIERLB.H - Hierarchial List Box Header File
//	Copyright  1993 by Microdyne Development Technologies.
//	All rights reserved.
//==============================================================================================

#ifndef _HIERLB_H
#define _HIERLB_H

#include <owl.h>
#include <listbox.h>
#include <wics.h>

#pragma option -Vo-
#if     defined(__BCOPT__) && !defined(_ALLOW_po)
#pragma option -po-
#endif

_CLASSDEF (THierarchialListBox)

class THierarchialListBox : public TListBox
{
private:
	virtual const Pchar streamableName() const { return "THierarchialListBox"; }

protected:
	virtual LPSTR GetClassName() { return "WICSHierList"; }

	THierarchialListBox(StreamableInit) : TListBox(streamableInit) {};

public:
	THierarchialListBox (PTWindowsObject AParent, UINT AnId);
	~THierarchialListBox ();

	virtual int AddString(LPSTR AString, HANDLE hSubTree, int index);
	virtual int AddString(LPSTR AString);
	virtual int FindString(LPSTR AString, int SearchIndex);
	virtual int FindString (LPSTR AString, HANDLE& hSubTree, int& index, BOOL fSubTableSearch);
	virtual int FindExactString(LPSTR AString, int SearchIndex);
	virtual int FindExactString(LPSTR AString, HANDLE& hSubTree, int&index, BOOL fSubTableSearch);
	virtual int DeleteString (int index);
	virtual int DeleteString (HANDLE hSubTree, int index);
	virtual int InsertString(LPSTR AString, int Index);
    virtual int InsertString(LPSTR AString, HANDLE hSubTree, int Index);
	virtual void ClearList();
	virtual int GetCount();
	virtual int GetCount(HANDLE hSubList);
	virtual HANDLE GetChildHandle (HANDLE hSubTree, int index);
	virtual int GetString(LPSTR AString, int Index);
    virtual int GetString(LPSTR AString, HANDLE hSubTree, int index);
	virtual int GetStringLen(int Index);
    virtual int GetStringLen(HANDLE hSubTree, int Index);
	virtual WORD Transfer(Pvoid DataPtr, WORD TransferFlag);

	virtual void OpenSubTree (HANDLE hParent, int index);
    virtual void CloseSubTree (HANDLE hParent, int index);

	// next four functions only for single-selection
	// list boxes (and combo boxes).

    virtual int GetSelString(LPSTR AString, int MaxChars);
	virtual int SetSelString(LPSTR AString, int SearchIndex);
	virtual int SetSelString(LPSTR AString, HANDLE& hSubTree, int& index, BOOL fSubTableSearch);
	virtual int GetSelIndex();
    virtual int GetSelIndex(HANDLE& hSubList);
	virtual int SetSelIndex(int Index);
	virtual int SetSelIndex(HANDLE hSubList, int index);

    virtual int GetSelCount();

	// next four functions only for multiple-selection list boxes.

    virtual int GetSelStrings(LPSTR *Strings, int MaxCount, int MaxChars);
	virtual int SetSelStrings(LPSTR *Prefixes, int NumSelections, BOOL ShouldSet);
    virtual int GetSelIndexes(long far * Indexes, int MaxCount);
	virtual int SetSelIndexes(long far * Indexes, int NumSelections, BOOL ShouldSet);
};

inline Ripstream operator >> ( Ripstream is, RTHierarchialListBox cl  ) { return is >> (RTStreamable )cl; }
inline Ripstream operator >> ( Ripstream is, RPTHierarchialListBox cl ) { return is >> (RPvoid)cl; }
inline Ropstream operator << ( Ropstream os, RTHierarchialListBox cl  ) { return os << (RTStreamable )cl; }
inline Ropstream operator << ( Ropstream os, PTHierarchialListBox cl  ) { return os << (PTStreamable )cl; }

#pragma option -Vo.
#if     defined(__BCOPT__) && !defined(_ALLOW_po)
#pragma option -po.
#endif

#endif

